@@ -41,7 +41,7 @@ serializing the result in the appropriate output format.
 
 package Web::DataService;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use parent qw(Exporter);
 
@@ -95,11 +95,9 @@ my (%DS_DEF) = ( 'name' => 'single',
 		 'doc_defs' => 'single',
 		 'doc_header' => 'single',
 		 'doc_footer' => 'single',
-		 'doc_layout' => 'single',
 		 'default_limit' => 'single',
 		 'streaming_threshold' => 'single',
-		 'allow_unrecognized' => 'single',
-		 'doc_dir' => 'single' );
+		 'allow_unrecognized' => 'single');
 
 our ($DEBUG);
 our ($ONE_REQUEST);
@@ -1287,6 +1285,16 @@ Define a ruleset with the given name, containing the specified rules and
 documentation.  The arguments to this method are simply passed on to the
 C<define_ruleset> method of L<HTTP::Validate>.
 
+=head3 define_block ( block_name, { attributes ... }, documentation ... )
+
+Define an output block with the given name, containing the specified output
+fields and documentation.
+
+=head3 define_set ( set_name, { attributes ... }, documentation ... )
+
+Define a set with the given name, containing the specified values and
+documentation.
+
 =head2 EXECUTION
 
 The following methods are available for you to use in the part of your code
